#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cborg-json
version:              0.2.2.0
visibility:           public
id:                   cborg-json-0.2.2.0-FGtoFn9OfrK1iwWZmiFYFp
key:                  cborg-json-0.2.2.0-FGtoFn9OfrK1iwWZmiFYFp
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  10590917bc85bfea94457be4558a67d3
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-8.10.5/site-local/cborg-json-0.2.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/cborg-json-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/cborg-json-0.2.2.0
hs-libraries:         HScborg-json-0.2.2.0-FGtoFn9OfrK1iwWZmiFYFp
depends:
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
    aeson-pretty-0.8.8-7Y85LeXJfbRBFaLbPECV89 base-4.14.2.0
    cborg-0.2.5.0-9EvLXFRKXWFK41IT7yryAK
    scientific-0.3.7.0-Ea1GK6jx8XDEEsfAKxwFym text-1.2.4.1
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

